//  @licstart The following is the entire license notice for the
//  JavaScript code in this page (or file).
//
//  This file is part of Linterna Mágica
//
// Copyright (C) 2010, 2011, 2012, 2013 Ivaylo Valkov <ivaylo@e-valkov.org>
// Copyright (C) 2010, 2011, 2012 Ivaylo Valkov <ivaylo@e-valkov.org>
// Copyright (C) 2010, 2011 Ivaylo Valkov <ivaylo@e-valkov.org>
// Copyright (C) 2010 Anton Katsarov <anton@katsarov.org>
// Copyright (C) 2011, 2012 Ivaylo Valkov <ivaylo@e-valkov.org>
// Copyright (C) 2011 Ivaylo Valkov <ivaylo@e-valkov.org>
// Copyright (C) 2012 Ivaylo Valkov <ivaylo@e-valkov.org>LinternaMagica.prototype.copyrights.push("Copyright (C) 2010, 2011, 2012,"+
//
// 
//  The JavaScript code in this page (or file) is free software: you
//  can redistribute it and/or modify it under the terms of the GNU
//  General Public License (GNU GPL) as published by the Free Software
//  Foundation, either version 3 of the License, or (at your option)
//  any later version.  The code is distributed WITHOUT ANY WARRANTY
//  without even the implied warranty of MERCHANTABILITY or FITNESS
//  FOR A PARTICULAR PURPOSE.  See the GNU GPL for more details.
//
//  As additional permission under GNU GPL version 3 section 7, you
//  may distribute non-source (e.g., minimized or compacted) forms of
//  that code without the copy of the GNU GPL normally required by
//  section 4, provided you include this license notice and a URL
//  through which recipients can access the Corresponding Source.
//
//  @licend The above is the entire license notice for the JavaScript
//  code in this page (or file).
//
// @source http://linterna-magica.nongnu.org

// ==UserScript==
// @name           Linterna Mágica l10n bg_BG
// @namespace Linterna Mágica
// @description  Bulgarian localisation for Linterna Mágica version 0.0.13.
// @include        http://*
// @include        https://*

// ==/UserScript==

var LM_L10N={"bg_BG":{ "__PO_HEADER":{
"Project-Id-Version":"linterna_magica svn-trunk", "Report-Msgid-Bugs-To":"",
"POT-Creation-Date":"2013-01-06 13:54+0200", "PO-Revision-Date":"2012-09-09 19:12+0300",
"Last-Translator":"Ivaylo Valkov <ivaylo@e-valkov.org>", "Language-Team":"Bulgarian <ivaylo@e-valkov.org>",
"Language":"bg", "MIME-Version":"1.0",
"Content-Type":"text/plain; charset=UTF-8", "Content-Transfer-Encoding":"8bit",},
 " version 3 (or later). " : " — версия 3 на лиценза или по-късна. ",
 " version: " : " версия: ",
 "A copy of the license can be downloaded from " : "Копие на лиценза можете да изтеглите от ",
 "About" : "Относно",
 "Apr" : "апр",
 "Aug" : "авг",
 "Buffering" : "Буфериране",
 "Click to change the size" : "Натиснете, за да промените размера",
 "Ctrl+double-click to select all messages" : "Натиснете два пъти с мишката докато държите клавиша Ctrl, за да изберете всички съобщения",
 "Date" : "Дата",
 "Debug messages" : "Отстраняване на грешки",
 "Dec" : "дек",
 "Double-click to change the size" : "Натиснете да пъти, за да промените размера",
 "Download" : "Запазване",
 "Feb" : "фев",
 "Fullscreen" : "На цял екран",
 "GNU  General Public License (GNU GPL)" : "Общия публичен лиценз на GNU (GNU GPL)",
 "HQ" : "ВК",
 "HTML5" : "HTML5",
 "Hide debug messages" : "Скриване на съобщенията за отстраняване на грешки",
 "Higher quality" : "Високо качество",
 "Jan" : "яну",
 "Jul" : "юли",
 "Jun" : "юни",
 "Link" : "Връза",
 "Linterna Mágica Home page" : "Уеб страница на Linterna Mágica",
 "Linterna Mágica error and debug messages" : "Съобщения за отстраняване на грешки в Linterna Mágica",
 "Linterna Mágica microbloging group at Identi.ca" : "Микроблог групата на Linterna Mágicа в Identi.ca",
 "Linterna Mágica project page at Savannah" : "Страница на проекта Linterna Mágica в Savannah",
 "Loading" : "Зареждане",
 "Loading video..." : "Зареждане на клипа…",
 "Mar" : "мар",
 "May" : "май",
 "Mute" : "Заглушаване",
 "Muted" : "Заглушен",
 "New version" : "Нова версия",
 "New version is available." : "Налична е нова версия.",
 "Noe" : "ное",
 "Oct" : "окт",
 "Pause" : "Пауза",
 "Play" : "Изпълнение",
 "Plugin" : "Приставка",
 "Progressive link" : "Връзка тип „Progressive“",
 "RTSP link" : "Връзка тип „RTSP“",
 "Read the news section at the home page" : "Прочетете новините на уеб страницата",
 "Remove log" : "Премахване на обекта",
 "Remove this button, if it overlaps images or text in the page." : "Премахнете този бутон, ако скрива изображения или текст от страницата.",
 "Remove update notifier" : "Премахване на обекта",
 "Report a bug at our Savannah project page" : "Подайте доклад за грешка на страницата на проекта в Savannah",
 "Save the video clip" : "Запазване на видео клипа",
 "Sep" : "сеп",
 "Switch between flash plugin and Linterna Mágica" : "Превключване между приставката за флаш и Linterna Mágica",
 "Switch between site's HTML5 player and Linterna Mágica" : "Превключване между възпрозивеждане чрез HTML5, предоставено от страницата и Linterna Mágica",
 "Switch between the Gnash plugin for flash and Linterna Mágica" : "Превключване между приставката Gnash и Linterna Mágica",
 "Switch between the Lightspark plugin for flash and Linterna Mágica" : "Превключване между приставката Lightspark и Linterna Mágica",
 "Switch between the Totem Vegas plugin for flash and Linterna Mágica" : "Превключване между приставката Totem Vegas и Linterna Mágica",
 "This program is free software; " : "Тази програма е свободен софтуер. ",
 "Time" : "Време",
 "Translation" : "Превод",
 "Unkown container" : "Непознат контейнер",
 "Unkown encoding" : "Непознато кодиране",
 "Unmute" : "Премахване на заглушаването",
 "Update" : "Обновление",
 "Volume control" : "Сила на звука",
 "Waiting for video plugin..." : "Изчакване на приставката за видео клипове…",
 "Waiting plugin" : "Изчакване на приставката",
 "Watch this video at it's original site with Linterna Mágica" : "Гледайте този видео клип на неговата уеб страница с Linterna Mágica",
 "Watch video on the web " : "Гледайте уеб видео клипове ",
 "You don't need a glint, " : "Нямате нужда от проблясъци, ",
 "__direction" : "ltr",
 "__translators" : "Ивайло Вълков <ivaylo@e-valkov.org>",
 "in a brand new way: " : "по напълно нов начин: ",
 "modify it under the terms of the " : "променяте под условията на ",
 "released at" : "публикувана на",
 "the magic lantern is ignited!" : "вълшебният фенер е разпален!",
 "you can redistribute it and/or " : "Можете да я разпространявате и/или ",},};

var head = document.getElementsByTagName("head")[0];
var script = document.createElement("script");

script.setAttribute("type", "text/javascript");

var script_data = 
    "if (window.LinternaMagica_L10N == undefined)"+
    "{"+
    "window.LinternaMagica_L10N = new Object();"+
    "}; ";

for (var o in LM_L10N)
{
    script_data += "window.LinternaMagica_L10N['"+o+ "'] = "; 
    if (/object/i.test(typeof(LM_L10N[o])))
    {
	script_data += "{";
	for (var oo in LM_L10N[o])
	{
	    if (/object/i.test(typeof(LM_L10N[o][oo])) &&
		typeof(LM_L10N[o][oo].join) != "undefined")
	    {
		// Array
		script_data += '"'+oo+ '" : ["' +
		    LM_L10N[o][oo].join('","')+'"],';
	    }
	    else if (/object/i.test(typeof(LM_L10N[o][oo])))
	    {
		// Object
		script_data += '"' +oo+'":{';
		for (var ooo in LM_L10N[o][oo])
		{
		    script_data += '"'+ooo+ '" : "' +LM_L10N[o][oo][ooo]+'",';
		}
		script_data +='},';
	    }
	    else
	    {
		// String or number
		script_data += '"'+oo+ '" : "' +LM_L10N[o][oo]+'",';
	    }
	}
	script_data += "};";
    }
    else
    {
	script_data += '"'+LM_L10N[o]+'"';
    }
}

script_data += ";";

script.textContent = script_data;

head.appendChild(script);

head.removeChild(script);
LM_L10N = undefined;
